@@ -13,14 +13,21 @@ import warnings
 import os
 import logging
 
+path = os.getcwd()
+
 LOG_TS = datetime.datetime.now().strftime("%Y.%m.%d.%H.%M.%S")
+logs_folder = os.path.join(os.getcwd(),'logs')
+if not os.path.exists(logs_folder):
+    os.makedirs(logs_folder)
+log_name = os.path.join(logs_folder, f'{os.path.basename(__file__).split(".")[0]}_log_{LOG_TS}.log')
+
 LOG_LEVEL = logging.DEBUG
 DELETE_FLAG = True
 TS = time()
 logger = logging.getLogger(__name__)
 logger.setLevel(LOG_LEVEL)
 formatter = logging.Formatter('%(asctime)s - %(levelname)s - %(message)s','%d/%m %H:%M:%S')
-fh = logging.FileHandler(filename = f'{".".join(__file__.split(".")[:-1])}_log_{LOG_TS}.log')
+fh = logging.FileHandler(filename = log_name)
 fh.setLevel(LOG_LEVEL)
 fh.setFormatter(formatter)
 logger.addHandler(fh)
@@ -30,10 +37,9 @@ Start_log = '#' * len(Test_case) * 3
 logger.info(Start_log)
 logger.info(Test_case)
 logger.info(Start_log)
-delete_old_log_files(directory = os.getcwd() ,delete_flag = DELETE_FLAG, logger = logger, extension_list = ['.log'],filename_list = ['autoCV_log_'],log_ts = LOG_TS)
+delete_old_log_files(directory = logs_folder ,delete_flag = DELETE_FLAG, logger = logger, extension_list = ['.log'],filename_list = ['autoCV_log'],log_ts = LOG_TS)
 logger.info(Test_comment)
 
-path = os.getcwd()
 
 def warn(*args, **kwargs):
     pass
